# Copyright Vespa.ai. Licensed under the terms of the Apache 2.0 license. See LICENSE in the project root.

# Version
%define ver_major 1
%define ver_minor 4
%define ver_patch 0
%define ver_release 1

%global _vespa_abseil_cpp_version 20250127.1
%global _vespa_gtest_version 1.16.0
%global _vespa_protobuf_version 5.30.1
%global _vespa_onnxruntime_version 1.20.1
%global _vespa_libzstd_version 1.5.6-1
%global _vespa_lz4_version 1.9.4-2
%global _vespa_toolset_version 14.2.1
%global _vespa_openblas_version 0.3.27
%if 0%{?fedora}
%if %{fedora} > 39
%global _vespa_java_version 21
%endif
%endif
%if 0%{?el10}
%global _vespa_java_version 21
%endif
%if ! 0%{?_vespa_java_version:1}
%global _vespa_java_version 17
%endif

Name:           vespa-build-dependencies
Version:        %{ver_major}.%{ver_minor}.%{ver_patch}
Release:        %{ver_release}%{?dist}
Summary:        Vespa - The open big data serving engine - build dependencies
Group:          Applications/Databases
License:        Apache-2.0
URL:            http://vespa.ai
BuildArch:      noarch

Requires: bison >= 3.0.0
Requires: flex >= 2.5.0
Requires: git
Requires: golang
Requires: libedit-devel
Requires: libicu-devel
Requires: make
Requires: perf
Requires: perl
Requires: perl-Getopt-Long
Requires: rpm-build
Requires: systemd
Requires: valgrind
Requires: zlib-devel

%if 0%{?el8}
%global _centos_stream %(grep -qs '^NAME="CentOS Stream"' /etc/os-release && echo 1 || echo 0)
Requires: cmake >= 3.11.4-3
Requires: gcc-toolset-14-gcc-c++
Requires: gcc-toolset-14-binutils
Requires: gcc-toolset-14-libatomic-devel
Requires: glibc-langpack-en
Requires: llvm-devel
Requires: maven
Requires: vespa-boost-devel >= 1.76.0-1
Requires: vespa-libzstd-devel >= %{_vespa_libzstd_version}
Requires: vespa-openblas-devel >= %{_vespa_openblas_version}
Requires: vespa-openssl-devel >= 3.1.7
Requires: vespa-gmock-devel = %{_vespa_gtest_version}
Requires: vespa-gtest-devel = %{_vespa_gtest_version}
Requires: vespa-lz4-devel >= %{_vespa_lz4_version}
Requires: vespa-onnxruntime-devel = %{_vespa_onnxruntime_version}
Requires: vespa-abseil-cpp-devel = %{_vespa_abseil_cpp_version}
Requires: vespa-protobuf-devel = %{_vespa_protobuf_version}
Requires: vespa-toolset-14-meta >= %{_vespa_toolset_version}
%endif

%if 0%{?el9}
%global _centos_stream %(grep -qs '^NAME="CentOS Stream"' /etc/os-release && echo 1 || echo 0)
Requires: boost-devel >= 1.75
Requires: cmake >= 3.20.2
Requires: gcc-toolset-14-gcc-c++
Requires: gcc-toolset-14-binutils
Requires: gcc-toolset-14-libatomic-devel
Requires: glibc-langpack-en
Requires: vespa-gmock-devel = %{_vespa_gtest_version}
Requires: vespa-gtest-devel = %{_vespa_gtest_version}
Requires: llvm-devel
Requires: maven
Requires: vespa-openblas-devel >= %{_vespa_openblas_version}
Requires: openssl-devel
Requires: vespa-libzstd-devel >= %{_vespa_libzstd_version}
Requires: vespa-lz4-devel >= %{_vespa_lz4_version}
Requires: vespa-onnxruntime-devel = %{_vespa_onnxruntime_version}
Requires: vespa-abseil-cpp-devel = %{_vespa_abseil_cpp_version}
Requires: vespa-protobuf-devel = %{_vespa_protobuf_version}
Requires: vespa-toolset-14-meta >= %{_vespa_toolset_version}
%endif

%if 0%{?el10}
%global _centos_stream %(grep -qs '^NAME="CentOS Stream"' /etc/os-release && echo 1 || echo 0)
Requires: boost-devel >= 1.83
Requires: cmake >= 3.30.5
Requires: gcc-c++
Requires: libatomic
Requires: glibc-langpack-en
Requires: gmock-devel
Requires: gtest-devel
Requires: llvm-devel
Requires: maven
Requires: vespa-openblas-devel >= %{_vespa_openblas_version}
Requires: openssl-devel
Requires: vespa-libzstd-devel >= %{_vespa_libzstd_version}
Requires: vespa-lz4-devel >= %{_vespa_lz4_version}
Requires: vespa-onnxruntime-devel = %{_vespa_onnxruntime_version}
Requires: abseil-cpp-devel
Requires: vespa-protobuf-devel = %{_vespa_protobuf_version}
%endif

%if 0%{?fedora}
Requires: boost-devel
Requires: cmake >= 3.9.1
Requires: gcc-c++
Requires: glibc-langpack-en
%if 0%{?amzn2023}
Requires: vespa-gmock-devel = %{_vespa_gtest_version}
Requires: vespa-gtest-devel = %{_vespa_gtest_version}
%else
Requires: gmock-devel
Requires: gtest-devel
%endif
Requires: libatomic
Requires: llvm-devel
Requires: maven
Requires: vespa-openblas-devel >= %{_vespa_openblas_version}
Requires: openssl-devel
%if 0%{?amzn2023}
Requires: vespa-abseil-cpp-devel = %{_vespa_abseil_cpp_version}
%else
Requires: abseil-cpp-devel
%endif
Requires: vespa-protobuf-devel = %{_vespa_protobuf_version}
Requires: vespa-lz4-devel >= %{_vespa_lz4_version}
Requires: vespa-onnxruntime-devel = %{_vespa_onnxruntime_version}
Requires: vespa-libzstd-devel >= %{_vespa_libzstd_version}

%endif

# For Amazon Linux 2023 fedora is also defined
%if 0%{?amzn2023}
Requires: java-17-amazon-corretto-devel
Requires: java-17-amazon-corretto
Requires: maven-amazon-corretto17
Requires: vespa-re2-devel = 20210801
Requires: vespa-xxhash-devel >= 0.8.1
%else
Requires: java-%{_vespa_java_version}-openjdk-devel
Requires: maven-openjdk%{_vespa_java_version}
Requires: re2-devel
Requires: xxhash-devel >= 0.8.1
%endif

%description

Vespa - The open big data serving engine - build dependencies

%files

%changelog
* Tue Mar 18 2025 Tor Egge <Tor.Egge@online.no> - 1.4.0
- Track upstream release of googletest 1.16.0
- Track upstream release of abseil-cpp 20250127.1
- track upstream release of protobuf 30.1
